import CEchart from './Base';
import echarts, { init } from 'echarts';
export default class DoughutPieChart extends CEchart {
    constructor(el, params) {
        super();
        this.el = el;
        this.params = params;
        this.suffix = '';
        this.showSuffix = true;
        this.subtext = '';
        this.data = [];
        this.count = 0;
        this.option = {
            tooltip: {
                formatter: '{b}: {c} ({d}%)'
            },
            title: {
                text: '{title|标题}',
                subtext: '{sub_title|子标题}',
                left: '-20%',
                top: 'center',
                textStyle: {
                    rich: {
                        title: {
                            align: 'center',
                            width: 160 - 10,
                            color: '#b1b2b3',
                            fontSize: 14,
                            lineHeight: 10,
                            padding: [15, 0, 0, 0]
                        },
                    },
                },
                subtextStyle: {
                    rich: {
                        sub_title: {
                            align: 'center',
                            fontSize: 16,
                            fontWeight: 'bold',
                            color: '#4f4f4f',
                            textShadowColor: '#ffffff',
                            padding: [10, 0, 0, 0],
                            width: 160 - 10,
                        }
                    }
                }
            },
            legend: {
                orient: 'vertical',
                right: 0,
                y: 'center',
                data: [],
                icon: "circle",
                formatter: (name) => {
                    let value = 0;
                    let percent = 0;
                    this.data.map(item => {
                        if (item.name === name) {
                            value = item.value;
                            percent = (item.value / this.count * 100).toFixed(2)
                        }
                    });
                    return '{a|' + name + '}' + '{b|' + value + '}' + '\t\t{c|' + percent + '%}'
                },
                textStyle: {
                    rich: {
                        a: {
                            width: 60,
                            padding: [0, 0, 5, 0]
                        },
                        b: {
                            padding: [0, 15, 5, 0],
                            color: "#ccc"
                        },
                        c: {
                            padding: [0, 0, 5, 0],
                        }
                    }
                }
            },
            series: {
                type: 'pie',
                radius: ['50%', '70%'],
                center: ['30%', '50%'],
                label: {
                    show: false,
                },
                color: ['#41A2FC', '#40CBCA', '#53CA77', '#F9D249', '#F0657D', '#9764E1'],
                labelLine: {
                    show: false
                },
                data: [],
                itemStyle: {
                    normal: {
                        borderWidth: 2,
                        borderColor: '#ffffff'
                    }
                }
            }
        };
        this.init(el);
    }
    // 重写
    init(el) {
        super.init(el);
        Object.keys(this.params).map(key => {
            switch (key) {
                case 'colors':
                    this.option.series[0].color = this.params[key];
                    break;
                case 'width':
                    el.style.width = this.params[key] + 'px';
                    this.option.title.textStyle.rich.title.width = this.params[key] - 10;
                    this.option.title.subtextStyle.rich.sub_title.width = this.params[key] - 10;
                    break;
                case 'height':
                    el.style.height = this.params[key] + 'px';
                    break;
                case 'title':
                    this.option.title.text = '{title|' + this.params[key] + '}';
                    break;
                case 'suffix':
                    this.option.tooltip.formatter = '{b}: {c}' + this.params[key] + ' ({d}%)';
                    this.suffix = this.params[key];
                    break;
                case 'data':
                    this.option.series.data = this.params[key];
                    this.data = this.params[key];
                    break;
                case 'countColor':
                    this.option.title.subtextStyle.rich.sub_title.color = this.params[key];
                    break;
                case 'showSuffix':
                    this.showSuffix = this.params[key];
                    break;
                case 'color':
                    this.option.series.color = this.params[key];
                    break;
            }
        });
        this.option.legend.data = this.option.series.data.map(item => {
            this.count += item.value;
            return { name: item.name }
        })
        this.subtext = this.count;
        if (this.showSuffix) {
            this.option.title.subtext = '{sub_title|' + this.subtext + this.suffix + '}';
        } else {
            this.option.title.subtext = '{sub_title|' + this.subtext + '}';
        }
        this.echart = echarts.init(el);
        this.echart.setOption(this.option);
    }
}