import CEchart from './Base';
import echarts, { init } from 'echarts';
export default class RatioPieChart extends CEchart {

  constructor(el, params) {
    super();
    this.el = el;
    this.params = params; this.option = {
      tooltip: {
        formatter: '{b}: {c} ({d}%)'
      },
      title: {
        text: '{title|总数}',
        subtext: '{sub_title|标题}',
        left: 'center',
        top: 'center',
        textStyle: {
          rich: {
            title: {
              fontSize: 30,
              lineHeight: 10,
              align: 'center',
            },
          },
        },
        subtextStyle: {
          rich: {
            sub_title: {
              align: 'center',
              fontSize: 12,
              color: '#999999',
              textShadowColor: '#ffffff',
              padding: [-25, 0, 0, 0]
            }
          }
        }
      },
      legend: {
        orient: 'horizontal',
        top: 0,
        x: 'center',
        data: [],
        itemGap: 10,
        padding: [0, 50, 0, 0],
        icon: "circle",
        type:'scroll',
        textStyle: {
          rich: {
            a: {
              width: 60,
              padding: [0, 5, 5, 0]
            },
            b: {
              padding: [0, 15, 5, 0],
              width: 45,
            },
            c: {
              padding: [0, 0, 5, 0],
            }
          }
        }
      },
      series: [
        {
          type: 'pie',
          radius: ['55%', '70%'],
          color: ['#3AC693', '#E4632C'],
          labelLine: {
            show: true,
            normal: {
              length: 10,
              length2: 60,
            }
          },
          label: {
            normal: {
              formatter: '{a|{d}%}\n{b|{c}}',
              padding: [0, -50],
              rich: {
                a: {
                  fontSize: 12,
                  lineHeight: 30
                },
                b: {
                  fontSize: 16,
                  fontWeight: 'bold',
                  lineHeight: 20,
                  color: '#333',
                  width: 50,
                  align: 'center'
                },
                detail_a: {
                  fontSize: 12,
                  lineHeight: 20
                },
                detail_b: {
                  fontSize: 12,
                  lineHeight: 20,
                  width: 50,
                  align: 'center',
                },
                reduce_a: {
                  fontSize: 12,
                },
                reduce_b: {
                  fontSize: 12,
                  fontWeight: 'bold',
                  color: '#333'
                }
              }
            }
          },
          data: []
        }
      ]
    }
    this.suffix = '';
    this.showSuffix = true;
    this.subtext = '';
    this.showValue = 'max';
    this.data = [];
    this.init(el);
  }
  // 重写
  init(el) {
    super.init(el);
    Object.keys(this.params).map(key => {
      switch (key) {
        case 'color':
          this.option.series[0].color = this.params[key];
          break;
        case 'width':
          el.style.width = this.params[key] + 'px';
          this.option.title.textStyle.rich.title.width = this.params[key] - 10;
          this.option.title.subtextStyle.rich.sub_title.width = this.params[key] - 10;
          break;
        case 'height':
          el.style.height = this.params[key] + 'px';
          break;
        case 'value':
          this.value = this.params[key];
          this.option.series[0].data[0].value = this.params[key];
          break;
        case 'title':
          this.option.title.subtext = '{sub_title|' + this.params[key] + '}';
          break;
        case 'name':
          this.option.series[0].data[0].name = this.params[key];
          break;
        case 'data':
          this.data = this.params[key];
          let count = 0;
          this.option.legend.data = this.params[key].map(item => {
            count += item.value;
            return item.name;
          });
          this.option.series[0].data = this.params[key];
          this.subtext = count;
          this.count = count;
          break;
        case 'legendPosition':
          if (this.params[key] === 'bottom') {
            this.option.legend.bottom = 0;
            delete this.option.legend.top;
          } else if (this.params[key] === 'left') {
            this.option.legend.left = 0;
            this.option.legend.y = 'center';
            this.option.legend.orient = 'vertical';
            delete this.option.legend.top;
          } else if (this.params[key] === 'right') {
            this.option.legend.left = '55%';
            this.option.legend.y = 'center';
            this.option.legend.orient = 'vertical';
            delete this.option.legend.x;
            delete this.option.legend.top;
          }
          break;
        case 'legendGap':
          this.option.legend.itemGap = this.params[key];
          break;
        case 'suffix':
          this.option.tooltip.formatter = '{b}: {c}' + this.params[key] + ' ({d}%)';
          this.suffix = this.params[key];
          break;
        case 'showSuffix':
          this.showSuffix = this.params[key];
          break;
        case 'showLegend':
          if (this.params[key] === false)
            delete this.option.legend;
          break;
        case 'showLabel':
          if (this.params[key] === false) {
            this.option.series[0].label = { show: false };
          }
          break;
        case 'noLine':
          this.option.series[0].labelLine.show = false;
          delete this.option.series[0].labelLine.normal;
          break;
        case 'mode':
          this.mode = this.params[key];
          if (this.params[key] === 'reduce') {
            this.option.series[0].label.normal.formatter = `{reduce_b|{c}${this.suffix}}{reduce_a|({d}%)}`;
            this.option.series[0].label.normal.padding = [0, -40];
          } else if (this.params[key] === 'detail') {
            this.option.series[0].label.normal.formatter = `{detail_a|{d}% ({c}${this.suffix})}\n{detail_b|{b}}`;
            this.option.series[0].label.normal.padding = [0, -60];
          } else if (this.params[key] === 'strange') {
            this.option.series[0].center = ['30%', '50%'];
            this.option.title.left = '-20%';
          }
          break;
        case 'other':
          this.option.series[0].data[1].name = this.params[key];
          break;
      }
    });
    if (this.showValue === 'value') {
      this.subtext = this.value;
    }
    if (this.mode === 'strange') {
      const data = this.data;
      const count = this.count;
      this.option.legend.formatter = (name) => {
        let value = 0;
        let percent = 0;
        data.map(item => {
          if (item.name === name) {
            value = item.value;
            percent = (item.value / count * 100).toFixed(2)
          }
        });
        return '{a|' + name + '}' + '{b|' + value + '}' + '\t\t{c|' + percent + '%}'
      }
    }
    this.option.title.text = '{title|' + this.subtext + '}';
    this.echart = echarts.init(el);
    this.echart.setOption(this.option);
  }
}