import CEchart from './Base';
import echarts, { init } from 'echarts';
export default class SingleRatioPieChart extends CEchart {
    constructor(el, params) {
        super();
        this.el = el;
        this.params = params; this.option = {
            tooltip: {
                formatter: '{b}: {c} ({d}%)'
            },
            title: {
                text: '{title|标题}',
                subtext: '{sub_title|子标题}',
                left: 'center',
                top: 'center',
                textStyle: {
                    rich: {
                        title: {
                            fontSize: 14,
                            fontWeight: 'bold',
                            lineHeight: 10,
                            padding: [15, 0, 0, 0]
                        },
                    },
                },
                subtextStyle: {
                    rich: {
                        sub_title: {
                            fontSize: 16,
                            fontWeight: 'bold',
                            color: '#4f4f4f',
                            textShadowColor: '#ffffff',
                            padding: [10, 0, 0, 0]
                        }
                    }
                }

            },
            series: [
                {
                    type: 'pie',
                    radius: ['50%', '70%'],
                    color: ['#42A3FC', '#F0F2F5'],//颜色
                    labelLine: {
                        show: false
                    },
                    data: [
                        { value: 0, name: '' },
                        { value: 0, name: '其他' },
                    ]
                }
            ]
        }
        this.suffix = '';
        this.showSuffix = true;
        this.value = 0;
        this.maxValue = 100;
        this.subtext = '';
        this.showValue = 'max';
        this.init(el);
    }
    // 重写
    init(el) {
        super.init(el);
        Object.keys(this.params).map(key => {
            switch (key) {
                case 'color':
                    this.option.series[0].color[0] = this.params[key];
                    break;
                case 'width':
                    el.style.width = this.params[key] + 'px';
                    break;
                case 'height':
                    el.style.height = this.params[key] + 'px';
                    break;
                case 'value':
                    this.value = this.params[key];
                    this.option.series[0].data[0].value = this.params[key];
                    break;
                case 'title':
                    this.option.title.text = '{title|' + this.params[key] + '}';
                    break;
                case 'name':
                    this.option.series[0].data[0].name = this.params[key];
                    break;
                case 'maxValue':
                    this.maxValue = this.params[key] > this.value ? this.params[key] : this.value;
                    this.subtext = this.params[key];
                    break;
                case 'suffix':
                    this.option.tooltip.formatter = '{b}: {c}' + this.params[key] + ' ({d}%)';
                    this.suffix = this.params[key];
                    break;
                case 'countColor':
                    this.option.title.subtextStyle.rich.sub_title.color = this.params[key];
                    break;
                case 'showSuffix':
                    this.showSuffix = this.params[key];
                    break;
                case 'showValue':
                    this.showValue = this.params[key];
                    break;
                case 'other':
                    this.option.series[0].data[1].name = this.params[key];
                    break;
            }
        });
        if (this.showValue === 'value') {
            this.subtext = this.value;
        }
        if (this.showSuffix) {
            this.option.title.subtext = '{sub_title|' + this.subtext + this.suffix + '}';
        } else {
            this.option.title.subtext = '{sub_title|' + this.subtext + '}';
        }
        this.option.series[0].data[1].value = this.maxValue - this.value;
        this.echart = echarts.init(el);
        this.echart.setOption(this.option);
    }
}